[hide private]
[frames] | no frames]

[ Module Hierarchy | Class Hierarchy ]

# Class Hierarchy

- gchecky.tools.decoder
- gchecky.tools.encoder
- object: The most base type
  - unittest.TestResult: Holder for test result information.
    - unittest._TextTestResult: A test result class that can print formatted text results to a stream.
  - exceptions.BaseException: Common base class for all exceptions
    - exceptions.Exception: Common base class for all non-exit exceptions.
      - exceptions.StandardError: Base class for all standard Python exceptions that do not represent interpreter exiting.
        - exceptions.AssertionError: Assertion failed.
      - gchecky.controller.GcheckyError: Base class for exception that could be thrown by gchecky library.
        - gchecky.controller.DataError: An exception of this class occures whenever there is error in converting python data to/from xml.
        - gchecky.controller.HandlerError: An exception of this class occures whenever an exception is thrown from user defined handler.
        - gchecky.controller.LibraryError: An exception of this class occures whenever there is a bug encountered in gchecky library.
        - gchecky.controller.SystemError: An exception of this class occures whenever there is a system error, such as network being unavailable or DB down.
      - gchecky.controller.ProcessingException
  - unittest.TestProgram: A command-line program that runs a set of tests; this is primarily for making test modules conveniently executable.
  - unittest._WritelnDecorator: Used to decorate file-like objects with a handy 'writeln' method
  - gchecky.gxml.Field: Holds all the meta-information about mapping the current field value into/from the xml DOM tree.
    - gchecky.gxml.Double: Floating point value
    - gchecky.gxml.Any: Any text value.
    - gchecky.gxml.Long
      - gchecky.gxml.Integer
    - gchecky.gxml.Decimal
    - gchecky.gxml.Complex: Represents a field which is not a simple POD but a complex data structure.
    - gchecky.gxml.String: Any text value.
      - gchecky.data.CountryCode
      - gchecky.data.PresentOrNot
      - gchecky.gxml.Pattern: A string matching a pattern.
        - gchecky.gxml.IP: Represents an IP address.
        - gchecky.gxml.Zip: Represents a zip code.
        - gchecky.gxml.Email
        - gchecky.gxml.LanguageCode
        - gchecky.gxml.Url: Note: a 'http://localhost/' does not considered to be a valid url.
        - gchecky.gxml.Phone
      - gchecky.gxml.ID
      - gchecky.gxml.Html
    - gchecky.gxml.Timestamp
    - gchecky.gxml.Boolean
    - gchecky.gxml.List: The field describes a homogene list of values which could be stored as a set of XML nodes with the same tag names.
  - gchecky.controller.html_order: TODO:
  - unittest.TestCase: A class whose instances are single test cases.
    - gchecky.test.gxml'.XmlFieldTestCase
    - gchecky.test.gxml'.XmlNodeTestCase
    - unittest.FunctionTestCase: A test case that wraps a test function.
    - gchecky.test.controller.ControllerTestCase
  - gchecky.controller.ControllerLevel_1
    - gchecky.controller.ControllerLevel_2
  - unittest.TestSuite: A test suite is a composite test consisting of a number of TestCases.
  - type: type(object) -> the object's type type(name, bases, dict) -> a new type
    - gchecky.gxml.NodeManager: The class keeps track of all the subclasses of `Node` class.
      - gchecky.gxml.DocumentManager: Keeps track of all the Document subclasses.
  - unittest.TestLoader: This class is responsible for loading tests according to various criteria and returning them wrapped in a Test
  - unittest.TextTestRunner: A test runner class that displays results in textual form.
  - gchecky.controller.ControllerContext
  - gchecky.gxml.Node: The base class for any class which represents data that could be mapped into XML DOM structure.
    - gchecky.model.shipping_in_calculate_t
    - gchecky.model.merchant_calculations_t
    - gchecky.model.digital_content_t
    - gchecky.model.tracking_data_t
    - gchecky.model.merchant_code_results_t
    - gchecky.gxml.Document: A Node which could be stored as a standalone xml document.
      - gchecky.model.abstract_order_t
        - gchecky.model.add_tracking_data_t: Represents a tag containing a request to add a shipper's tracking number to an order.
        - gchecky.model.authorize_order_t
        - gchecky.model.archive_order_t: Represents a request to archive a particular order.
        - gchecky.model.send_buyer_message_t
        - gchecky.model.process_order_t
        - gchecky.model.refund_order_t
        - gchecky.model.add_merchant_order_number_t
        - gchecky.model.unarchive_order_t
        - gchecky.model.deliver_order_t
        - gchecky.model.cancel_order_t: Represents an order that should be canceled.
        - gchecky.model.charge_order_t
      - gchecky.model.checkout_shopping_cart_t
      - gchecky.model.error_t: Represents a response containing information about an invalid API request.
      - gchecky.model.checkout_redirect_t: Try doctests: >>> a = checkout_redirect_t(serial_number='blabla12345', ...
      - gchecky.model.notification_acknowledgment_t
      - gchecky.model.ok_t
      - gchecky.model.bye_t: Represents a response that indicates that Google correctly received a <hello> request.
      - gchecky.model.abstract_notification_t
        - gchecky.model.authorization_amount_notification_t
        - gchecky.model.charge_amount_notification_t: Represents information about a successful charge for an order.
        - gchecky.model.refund_amount_notification_t
        - gchecky.model.new_order_notification_t
        - gchecky.model.chargeback_amount_notification_t
        - gchecky.model.order_state_change_notification_t
        - gchecky.model.risk_information_notification_t
      - gchecky.model.merchant_calculation_results_t
      - gchecky.model.merchant_calculation_callback_t
      - gchecky.model.hello_t: Represents a simple test that verifies that your server communicates properly with Google Checkout.
      - gchecky.model.request_received_t
      - gchecky.model.diagnosis_t: Represents a diagnostic response to an API request.
      - gchecky.model.demo_failure_t:
    - gchecky.model.url_parameter_t
    - gchecky.model.buyer_marketing_preferences_t
    - gchecky.model.item_t:
    - gchecky.model.risk_information_t
    - gchecky.model.shipping_option_t: Represents information about shipping costs.
      - gchecky.model.flat_rate_shipping_t
      - gchecky.model.merchant_calculated_shipping_t
    - gchecky.model.shopping_cart_t
    - gchecky.model.price_t
    - gchecky.model.checkout_flow_support_t:
    - gchecky.model.alternate_tax_table_t
    - gchecky.model.merchant_code_string_t
    - gchecky.model.tax_area_t
    - gchecky.model.result_t
    - gchecky.model.tax_tables_t
    - gchecky.model.pickup_t
    - gchecky.model.discount_result_t
    - gchecky.model.calculate_t
    - gchecky.model.postal_area_t:
    - gchecky.model.shipping_in_order_adjustment_t
    - gchecky.model.default_tax_table_t
    - gchecky.model.order_adjustment_t
    - gchecky.model.anonymous_address_t
    - gchecky.model.shipping_methods_t
    - gchecky.model.address_t
      - gchecky.model.billing_address_t
      - gchecky.model.buyer_billing_address_t
      - gchecky.model.buyer_shipping_address_t
    - gchecky.model.parameterized_url_t
    - gchecky.model.shipping_adjustment_t
    - gchecky.model.areas_t: Represents a list of regions.
      - gchecky.model.allowed_areas_t
      - gchecky.model.excluded_areas_t
    - gchecky.model.tax_rule_t
      - gchecky.model.alternate_tax_rule_t
      - gchecky.model.default_tax_rule_t
    - gchecky.model.merchant_codes_t
    - gchecky.model.coupon_gift_adjustment_t